componenttools.get_proper_descendents_of_component
==================================================

.. autofunction:: abjad.tools.componenttools.get_proper_descendents_of_component.get_proper_descendents_of_component
   :noindex:
